@@ -39,9 +39,20 @@ test_that("check_suggested_exp_funcs returns matches messages for S3 functions",
   r["CRAN"] = "http://cran.us.r-project.org"
   options(repos = r)
 
-  dp <- system.file("test-data", "test.package.0009_0.1.0.tar.gz",
-                    package = "risk.assessr")
-
+  # Copy test package to a temp file
+  dp_orig <- system.file("test-data", 
+                         "test.package.0009_0.1.0.tar.gz", 
+                         package = "risk.assessr")
+  dp <- tempfile(fileext = ".tar.gz")
+  file.copy(dp_orig, dp)
+  
+  # Defer cleanup of copied tarball
+  withr::defer(unlink(dp), envir = parent.frame())
+  
+  # Defer cleanup of unpacked source directory
+  withr::defer(unlink(pkg_source_path, recursive = TRUE, force = TRUE),
+               envir = parent.frame())
+  
   # set up package
   install_list <- risk.assessr::set_up_pkg(dp)
 
@@ -267,9 +278,20 @@ test_that("check_suggested_exp_funcs returns matches messages for S3 functions",
   r["CRAN"] = "http://cran.us.r-project.org"
   options(repos = r)
 
-  dp <- system.file("test-data", "test.package.0009_0.1.0.tar.gz",
-                    package = "risk.assessr")
-
+  # Copy test package to a temp file
+  dp_orig <- system.file("test-data", 
+                         "test.package.0009_0.1.0.tar.gz", 
+                         package = "risk.assessr")
+  dp <- tempfile(fileext = ".tar.gz")
+  file.copy(dp_orig, dp)
+  
+  # Defer cleanup of copied tarball
+  withr::defer(unlink(dp), envir = parent.frame())
+  
+  # Defer cleanup of unpacked source directory
+  withr::defer(unlink(pkg_source_path, recursive = TRUE, force = TRUE),
+               envir = parent.frame())
+  
   # set up package
   install_list <- risk.assessr::set_up_pkg(dp)
 
@@ -316,8 +338,19 @@ test_that("check_suggested_exp_funcs returns matches messages for S4 functions",
   r["CRAN"] = "http://cran.us.r-project.org"
   options(repos = r)
   
-  dp <- system.file("test-data", "test.package.0010_0.1.0.tar.gz", 
-                    package = "risk.assessr")
+  # Copy test package to a temp file
+  dp_orig <- system.file("test-data", 
+                         "test.package.0010_0.1.0.tar.gz", 
+                         package = "risk.assessr")
+  dp <- tempfile(fileext = ".tar.gz")
+  file.copy(dp_orig, dp)
+  
+  # Defer cleanup of copied tarball
+  withr::defer(unlink(dp), envir = parent.frame())
+  
+  # Defer cleanup of unpacked source directory
+  withr::defer(unlink(pkg_source_path, recursive = TRUE, force = TRUE),
+               envir = parent.frame())
   
   # set up package
   install_list <- set_up_pkg(dp)
@@ -365,8 +398,19 @@ test_that("check_suggested_exp_funcs returns no exported functions message", {
   r["CRAN"] = "http://cran.us.r-project.org"
   options(repos = r)
   
-  dp <- system.file("test-data", "test.package.0005_0.1.0.tar.gz", 
-                    package = "risk.assessr")
+  # Copy test package to a temp file
+  dp_orig <- system.file("test-data", 
+                         "test.package.0005_0.1.0.tar.gz", 
+                         package = "risk.assessr")
+  dp <- tempfile(fileext = ".tar.gz")
+  file.copy(dp_orig, dp)
+  
+  # Defer cleanup of copied tarball
+  withr::defer(unlink(dp), envir = parent.frame())
+  
+  # Defer cleanup of unpacked source directory
+  withr::defer(unlink(pkg_source_path, recursive = TRUE, force = TRUE),
+               envir = parent.frame())
   
   # set up package
   install_list <- set_up_pkg(dp)
@@ -418,8 +462,19 @@ test_that("check_suggested_exp_funcs returns No R folder found in the package so
   r["CRAN"] = "http://cran.us.r-project.org"
   options(repos = r)
   
-  dp <- system.file("test-data", "test.package.0006_0.1.0.tar.gz", 
-                    package = "risk.assessr")
+  # Copy test package to a temp file
+  dp_orig <- system.file("test-data", 
+                         "test.package.0006_0.1.0.tar.gz", 
+                         package = "risk.assessr")
+  dp <- tempfile(fileext = ".tar.gz")
+  file.copy(dp_orig, dp)
+  
+  # Defer cleanup of copied tarball
+  withr::defer(unlink(dp), envir = parent.frame())
+  
+  # Defer cleanup of unpacked source directory
+  withr::defer(unlink(pkg_source_path, recursive = TRUE, force = TRUE),
+               envir = parent.frame())
   
   # set up package
   install_list <- set_up_pkg(dp)
